anbocas_tickets_api library

Exceptions / Errors

AnbocasAPIException
Custom Exception for the plugin, Thrown whenever the API responds with an error and body could not be parsed.
AnbocasFieldException